@@ -24,6 +24,7 @@
 #include "netk-window.h"
 #include "netk-private.h"
 
+#define NETK_CLASS_GROUP_GET_PRIVATE(o)    (G_TYPE_INSTANCE_GET_PRIVATE ((o), NETK_TYPE_CLASS_GROUP, NetkClassGroupPrivate))
 
 /* Private part of the NetkClassGroup structure */
 struct _NetkClassGroupPrivate
@@ -57,7 +58,7 @@ enum
 
 static guint signals[LAST_SIGNAL] = { 0 };
 
-static gpointer *parent_class;
+static GObjectClass *parent_class;
 
 
 GType
@@ -90,11 +91,13 @@ netk_class_group_get_type (void)
 }
 
 static void
-netk_class_group_class_init (NetkClassGroupClass * class)
+netk_class_group_class_init (NetkClassGroupClass * klass)
 {
-    GObjectClass *gobject_class = G_OBJECT_CLASS (class);
+    GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
+    
+    g_type_class_add_private (klass, sizeof (NetkClassGroupPrivate));
 
-    parent_class = g_type_class_peek_parent (class);
+    parent_class = g_type_class_peek_parent (klass);
 
     gobject_class->finalize = netk_class_group_finalize;
 
@@ -115,43 +118,36 @@ netk_class_group_class_init (NetkClassGroupClass * class)
 static void
 netk_class_group_init (NetkClassGroup * class_group)
 {
-    NetkClassGroupPrivate *priv;
+    class_group->priv = NETK_CLASS_GROUP_GET_PRIVATE (class_group);
+    
+    class_group->priv->res_class = NULL;
+    class_group->priv->name = NULL;
+    class_group->priv->windows = NULL;
 
-    priv = g_new (NetkClassGroupPrivate, 1);
-    class_group->priv = priv;
-
-    priv->res_class = NULL;
-    priv->name = NULL;
-    priv->windows = NULL;
-
-    priv->icon = NULL;
-    priv->mini_icon = NULL;
+    class_group->priv->icon = NULL;
+    class_group->priv->mini_icon = NULL;
 }
 
 static void
 netk_class_group_finalize (GObject * object)
 {
     NetkClassGroup *class_group;
-    NetkClassGroupPrivate *priv;
 
     class_group = NETK_CLASS_GROUP (object);
-    priv = class_group->priv;
 
-    if (priv->res_class)
-        g_free (priv->res_class);
+    if (class_group->priv->res_class)
+        g_free (class_group->priv->res_class);
 
-    if (priv->name)
-        g_free (priv->name);
+    if (class_group->priv->name)
+        g_free (class_group->priv->name);
 
-    g_list_free (priv->windows);
+    g_list_free (class_group->priv->windows);
 
-    if (priv->icon)
-        g_object_unref (priv->icon);
+    if (class_group->priv->icon)
+        g_object_unref (G_OBJECT (class_group->priv->icon));
 
-    if (priv->mini_icon)
-        g_object_unref (priv->mini_icon);
-
-    g_free (priv);
+    if (class_group->priv->mini_icon)
+        g_object_unref (G_OBJECT (class_group->priv->mini_icon));
 
     G_OBJECT_CLASS (parent_class)->finalize (object);
 }
@@ -190,7 +186,6 @@ NetkClassGroup *
 p_netk_class_group_create (const char *res_class)
 {
     NetkClassGroup *class_group;
-    NetkClassGroupPrivate *priv;
 
     if (class_group_hash == NULL)
         class_group_hash = g_hash_table_new (g_str_hash, g_str_equal);
@@ -199,11 +194,10 @@ p_netk_class_group_create (const char *res_class)
         (class_group_hash, res_class ? res_class : "") == NULL, NULL);
 
     class_group = g_object_new (NETK_TYPE_CLASS_GROUP, NULL);
-    priv = class_group->priv;
 
-    priv->res_class = g_strdup (res_class ? res_class : "");
+    class_group->priv->res_class = g_strdup (res_class ? res_class : "");
 
-    g_hash_table_insert (class_group_hash, priv->res_class, class_group);
+    g_hash_table_insert (class_group_hash, class_group->priv->res_class, class_group);
     /* Hash now owns one ref, caller gets none */
 
     return class_group;
@@ -218,37 +212,30 @@ p_netk_class_group_create (const char *res_class)
 void
 p_netk_class_group_destroy (NetkClassGroup * class_group)
 {
-    NetkClassGroupPrivate *priv;
-
     g_return_if_fail (NETK_IS_CLASS_GROUP (class_group));
 
-    priv = class_group->priv;
+    g_hash_table_remove (class_group_hash, class_group->priv->res_class);
 
-    g_hash_table_remove (class_group_hash, priv->res_class);
-
-    g_free (priv->res_class);
-    priv->res_class = NULL;
+    g_free (class_group->priv->res_class);
+    class_group->priv->res_class = NULL;
 
     /* remove hash's ref on the class group */
-    g_object_unref (class_group);
+    g_object_unref (G_OBJECT (class_group));
 }
 
 static const char *
 get_name_from_applications (NetkClassGroup * class_group)
 {
-    NetkClassGroupPrivate *priv;
     const char *first_name;
     GList *l;
 
-    priv = class_group->priv;
-
     /* Try to get the name from the group leaders.  If all have the same name, we
      * can use that.
      */
 
     first_name = NULL;
 
-    for (l = priv->windows; l; l = l->next)
+    for (l = class_group->priv->windows; l; l = l->next)
     {
         NetkWindow *w;
         NetkApplication *app;
@@ -282,19 +269,16 @@ get_name_from_applications (NetkClassGroup * class_group)
 static const char *
 get_name_from_windows (NetkClassGroup * class_group)
 {
-    NetkClassGroupPrivate *priv;
     const char *first_name;
     GList *l;
 
-    priv = class_group->priv;
-
     /* Try to get the name from windows, following the same rationale as
      * get_name_from_applications()
      */
 
     first_name = NULL;
 
-    for (l = priv->windows; l; l = l->next)
+    for (l = class_group->priv->windows; l; l = l->next)
     {
         NetkWindow *window;
 
@@ -323,15 +307,12 @@ get_name_from_windows (NetkClassGroup * class_group)
 static void
 set_name (NetkClassGroup * class_group)
 {
-    NetkClassGroupPrivate *priv;
     const char *new_name;
 
-    priv = class_group->priv;
-
-    if (priv->name)
+    if (class_group->priv->name)
     {
-        g_free (priv->name);
-        priv->name = NULL;
+        g_free (class_group->priv->name);
+        class_group->priv->name = NULL;
     }
 
     new_name = get_name_from_applications (class_group);
@@ -341,15 +322,15 @@ set_name (NetkClassGroup * class_group)
         new_name = get_name_from_windows (class_group);
 
         if (!new_name)
-            new_name = priv->res_class;
+            new_name = class_group->priv->res_class;
     }
 
     g_assert (new_name != NULL);
 
-    if (!priv->name || g_utf8_collate (priv->name, new_name) != 0)
+    if (!class_group->priv->name || g_utf8_collate (class_group->priv->name, new_name) != 0)
     {
-        g_free (priv->name);
-        priv->name = g_strdup (new_name);
+        g_free (class_group->priv->name);
+        class_group->priv->name = g_strdup (new_name);
 
         g_signal_emit (G_OBJECT (class_group), signals[NAME_CHANGED], 0);
     }
@@ -360,15 +341,12 @@ static void
 get_icons_from_applications (NetkClassGroup * class_group, GdkPixbuf ** icon,
     GdkPixbuf ** mini_icon)
 {
-    NetkClassGroupPrivate *priv;
     GList *l;
 
-    priv = class_group->priv;
-
     *icon = NULL;
     *mini_icon = NULL;
 
-    for (l = priv->windows; l; l = l->next)
+    for (l = class_group->priv->windows; l; l = l->next)
     {
         NetkWindow *window;
         NetkApplication *app;
@@ -396,15 +374,12 @@ static void
 get_icons_from_windows (NetkClassGroup * class_group, GdkPixbuf ** icon,
     GdkPixbuf ** mini_icon)
 {
-    NetkClassGroupPrivate *priv;
     GList *l;
 
-    priv = class_group->priv;
-
     *icon = NULL;
     *mini_icon = NULL;
 
-    for (l = priv->windows; l; l = l->next)
+    for (l = class_group->priv->windows; l; l = l->next)
     {
         NetkWindow *window;
 
@@ -429,11 +404,8 @@ get_icons_from_windows (NetkClassGroup * class_group, GdkPixbuf ** icon,
 static void
 set_icon (NetkClassGroup * class_group)
 {
-    NetkClassGroupPrivate *priv;
     GdkPixbuf *icon, *mini_icon;
 
-    priv = class_group->priv;
-
     get_icons_from_applications (class_group, &icon, &mini_icon);
 
     if (!icon || !mini_icon)
@@ -445,14 +417,14 @@ set_icon (NetkClassGroup * class_group)
 
     g_assert (icon && mini_icon);
 
-    if (priv->icon)
-        g_object_unref (priv->icon);
+    if (class_group->priv->icon)
+        g_object_unref (G_OBJECT (class_group->priv->icon));
 
-    if (priv->mini_icon)
-        g_object_unref (priv->mini_icon);
+    if (class_group->priv->mini_icon)
+        g_object_unref (G_OBJECT (class_group->priv->mini_icon));
 
-    priv->icon = g_object_ref (icon);
-    priv->mini_icon = g_object_ref (mini_icon);
+    class_group->priv->icon = g_object_ref (G_OBJECT (icon));
+    class_group->priv->mini_icon = g_object_ref (G_OBJECT (mini_icon));
 
     g_signal_emit (G_OBJECT (class_group), signals[ICON_CHANGED], 0);
 }
@@ -469,15 +441,11 @@ void
 p_netk_class_group_add_window (NetkClassGroup * class_group,
     NetkWindow * window)
 {
-    NetkClassGroupPrivate *priv;
-
     g_return_if_fail (NETK_IS_CLASS_GROUP (class_group));
     g_return_if_fail (NETK_IS_WINDOW (window));
     g_return_if_fail (netk_window_get_class_group (window) == NULL);
 
-    priv = class_group->priv;
-
-    priv->windows = g_list_prepend (priv->windows, window);
+    class_group->priv->windows = g_list_prepend (class_group->priv->windows, window);
     p_netk_window_set_class_group (window, class_group);
 
     set_name (class_group);
@@ -500,15 +468,11 @@ void
 p_netk_class_group_remove_window (NetkClassGroup * class_group,
     NetkWindow * window)
 {
-    NetkClassGroupPrivate *priv;
-
     g_return_if_fail (NETK_IS_CLASS_GROUP (class_group));
     g_return_if_fail (NETK_IS_WINDOW (window));
     g_return_if_fail (netk_window_get_class_group (window) == class_group);
 
-    priv = class_group->priv;
-
-    priv->windows = g_list_remove (priv->windows, window);
+    class_group->priv->windows = g_list_remove (class_group->priv->windows, window);
     p_netk_window_set_class_group (window, NULL);
 }
 
@@ -524,12 +488,9 @@ p_netk_class_group_remove_window (NetkClassGroup * class_group,
 GList *
 netk_class_group_get_windows (NetkClassGroup * class_group)
 {
-    NetkClassGroupPrivate *priv;
-
     g_return_val_if_fail (class_group != NULL, NULL);
 
-    priv = class_group->priv;
-    return priv->windows;
+    return class_group->priv->windows;
 }
 
 /**
@@ -544,12 +505,9 @@ netk_class_group_get_windows (NetkClassGroup * class_group)
 const char *
 netk_class_group_get_res_class (NetkClassGroup * class_group)
 {
-    NetkClassGroupPrivate *priv;
-
     g_return_val_if_fail (class_group != NULL, NULL);
 
-    priv = class_group->priv;
-    return priv->res_class;
+    return class_group->priv->res_class;
 }
 
 /**
@@ -563,13 +521,9 @@ netk_class_group_get_res_class (NetkClassGroup * class_group)
 const char *
 netk_class_group_get_name (NetkClassGroup * class_group)
 {
-    NetkClassGroupPrivate *priv;
-
     g_return_val_if_fail (class_group != NULL, NULL);
 
-    priv = class_group->priv;
-
-    return priv->name;
+    return class_group->priv->name;
 }
 
 /**
@@ -583,13 +537,9 @@ netk_class_group_get_name (NetkClassGroup * class_group)
 GdkPixbuf *
 netk_class_group_get_icon (NetkClassGroup * class_group)
 {
-    NetkClassGroupPrivate *priv;
-
     g_return_val_if_fail (class_group != NULL, NULL);
 
-    priv = class_group->priv;
-
-    return priv->icon;
+    return class_group->priv->icon;
 }
 
 /**
@@ -603,11 +553,7 @@ netk_class_group_get_icon (NetkClassGroup * class_group)
 GdkPixbuf *
 netk_class_group_get_mini_icon (NetkClassGroup * class_group)
 {
-    NetkClassGroupPrivate *priv;
-
     g_return_val_if_fail (class_group != NULL, NULL);
 
-    priv = class_group->priv;
-
-    return priv->mini_icon;
+    return class_group->priv->mini_icon;
 }
