@@ -33,6 +33,17 @@
 
 G_BEGIN_DECLS
 
+/* support macros for the slice allocator */
+#if GLIB_CHECK_VERSION(2,10,0)
+#define _netk_slice_new(type)                     (g_slice_new (type))
+#define _netk_slice_new0(type)                    (g_slice_new0 (type))
+#define _netk_slice_free(type, ptr)               G_STMT_START{ g_slice_free (type, (ptr)); }G_STMT_END
+#else
+#define _netk_slice_new(type)                     (g_new (type, 1))
+#define _netk_slice_new0(type)                    (g_new0 (type, 1))
+#define _netk_slice_free(type, ptr)               G_STMT_START{ g_free ((ptr)); }G_STMT_END
+#endif
+
 void p_netk_application_process_property_notify (NetkApplication * app,
                                                  XEvent * xevent);
 void p_netk_window_process_property_notify (NetkWindow * window,
