@@ -1690,7 +1690,7 @@ p_netk_icon_cache_new (void)
 {
     NetkIconCache *icon_cache;
 
-    icon_cache = g_new0 (NetkIconCache, 1);
+    icon_cache = _netk_slice_new0 (NetkIconCache);
 
     icon_cache->origin = USING_NO_ICON;
     icon_cache->prev_pixmap = None;
@@ -1734,7 +1734,7 @@ p_netk_icon_cache_free (NetkIconCache * icon_cache)
 {
     clear_icon_cache (icon_cache, FALSE);
 
-    g_free (icon_cache);
+    _netk_slice_free (NetkIconCache, icon_cache);
 }
 
 void
@@ -1832,7 +1832,7 @@ scaled_from_pixdata (guchar * pixdata, int w, int h, int new_w, int new_h)
             gdk_pixbuf_copy_area (src, 0, 0, w, h, tmp, (size - w) / 2,
                                   (size - h) / 2);
 
-            g_object_unref (src);
+            g_object_unref (G_OBJECT (src));
             src = tmp;
         }
     }
@@ -2357,7 +2357,7 @@ p_netk_try_desktop_layout_manager (Screen * xscreen, int current_token)
 
     /* No one in-process has the selection at the moment */
 
-    lm = g_new0 (LayoutManager, 1);
+    lm = _netk_slice_new0 (LayoutManager);
 
     lm->screen_number = number;
     lm->token = next_token;
@@ -2382,7 +2382,7 @@ p_netk_try_desktop_layout_manager (Screen * xscreen, int current_token)
 
     if (XGetSelectionOwner (gdk_display, lm->selection_atom) != lm->window)
     {
-        g_free (lm);
+        _netk_slice_free (LayoutManager, lm);
         return NETK_NO_MANAGER_TOKEN;
     }
 
@@ -2424,7 +2424,7 @@ p_netk_release_desktop_layout_manager (Screen * xscreen, int current_token)
             {
                 XDestroyWindow (gdk_display, lm->window);
 
-                g_free (lm);
+                _netk_slice_free (LayoutManager, lm);
                 layout_managers = g_slist_remove (layout_managers, lm);
 
                 return;
@@ -2454,7 +2454,7 @@ p_netk_desktop_layout_manager_process_event (XEvent * xev)
         {
             XDestroyWindow (gdk_display, lm->window);
 
-            g_free (lm);
+            _netk_slice_free (LayoutManager, lm);
             layout_managers = g_slist_remove (layout_managers, lm);
 
             return TRUE;
